@@ -6,7 +6,7 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( download_youtube );
+our @EXPORT_OK = qw( download_youtube is_in_download_archive );
 
 use File::Basename        qw( basename );
 use File::Spec::Functions qw( catfile );
@@ -22,7 +22,7 @@ use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
 use App::YTDL::GetData qw( get_new_video_url );
 use App::YTDL::Helper  qw( sec_to_time encode_fs check_mapping_stdout timestamp_to_upload_date HIDE_CURSOR SHOW_CURSOR
-                           read_json write_json );
+                           read_json write_json format_bytes_per_sec );
 
 END { print SHOW_CURSOR }
 
@@ -36,12 +36,12 @@ sub download_youtube {
             for my $fmt ( sort keys %{$info->{$ex}{$video_id}{file_name}} ) {
                 my $file_name = $info->{$ex}{$video_id}{file_name}{$fmt};
                 $nr++;
-                if ( $opt->{skip_archived_videos} && _is_in_download_archive( $opt, $info, $ex, $video_id, $fmt ) ) {
+                if ( $opt->{skip_archived_videos} && is_in_download_archive( $opt, $info, $ex, $video_id, $fmt ) ) {
                     push @{$opt->{skipped_archived_videos}}, sprintf "%s - %s", $video_id, $info->{$ex}{$video_id}{title}; #
                     my $video_count = sprintf "%*s from %s", length $opt->{nr_videos}, $nr, $opt->{nr_videos};
                     printf "  %s\n", '-' x length $video_count if $nr > 1;
                     printf "  %s (%s)\n", check_mapping_stdout( $opt, basename $file_name ), $info->{$ex}{$video_id}{duration} // '?';
-                    printf "  %s   Skipped\n", $video_count;
+                    printf "  %s   Skipped (download archive)\n", $video_count;
                     next;
                 }
                 if ( ! eval {
@@ -139,7 +139,7 @@ sub _status {
     print cldown;
     if ( $status && $status =~ /^(200|206|416)/ ) {
         my $file_size = -s encode_fs( $opt, $file_name ) // -1;
-        my $avg_speed = sprintf "avg %2sk/s", $p->{kbs_avg} || '--';
+        my $avg_speed = format_bytes_per_sec( $p->{avg_bytes_per_sec} );
         my ( $size, $at, $incomplete ) = ( '' ) x 4;
         if ( $p->{total} ) {
             my $len_total_mb = length( int( $p->{total} / 1024 ** 2 ) );
@@ -156,20 +156,19 @@ sub _status {
                 $retries    = sprintf "%*s/%s", length $opt->{retries}, $try, $opt->{retries};
             }
         }
-        my $pr_status = 'status ' . $status;
         if ( $status == 416 ) {
+            my $pr_status = 'status ' . $status;
             $dl_time   = ' ' x length '0:00:00';
             printf _p_fmt( $opt, "status_416" ), $video_count, $retries, $dl_time, $at, $pr_status;
             return 2;
         }
         elsif ( $status == 200 ) {
             my $at        = ' ' x length $at;
-            my $pr_status = ' ' x length $pr_status;
-            printf _p_fmt( $opt, "status" ), $video_count, $retries, $dl_time, $size, $avg_speed, $at, $pr_status, $incomplete;
+            printf _p_fmt( $opt, "status" ), $video_count, $retries, $dl_time, $size, $avg_speed, $at, $incomplete;
             return 1 if $p->{total} && $p->{total} == $file_size;
         }
         else {
-            printf _p_fmt( $opt, "status" ), $video_count, $retries, $dl_time, $size, $avg_speed, $at, $pr_status, $incomplete;
+            printf _p_fmt( $opt, "status" ), $video_count, $retries, $dl_time, $size, $avg_speed, $at, $incomplete;
             return 1 if $p->{total} && $p->{total} == $file_size;
         }
     }
@@ -195,14 +194,13 @@ sub _status {
 
 sub _p_fmt {
     my ( $opt, $key ) = @_;
-    my $sl = $opt->{kb_sec_len} + 7;
     my %hash = (
         start        => "  %s  %s  %9s\n",
         status_416   => "  %s  %s  %s  %9s   %s\n",
-        status       => "  %s  %s  %s  %9s  %${sl}s   %s    %s  %s\n",
+        status       => "  %s  %s  %s  %9s  %11s   %s   %s\n",
         status_err   => "  %s  %s      %s\n",
-        info_row1    => "%9.*f %s %37s %"    . (      $opt->{kb_sec_len} ) . "sk/s\n",
-        info_row2    => "%9.*f %s %6.*f%% %" . ( 30 + $opt->{kb_sec_len} ) . "sk/s\n",
+        info_row1    => "%9.*f %s %36s %9s\n",
+        info_row2    => "%9.*f %s %6.1f%% %38s\n",
         info_nt_row1 => " %34s %24sk/s\n",
         info_nt_row2 => "%9.*f %s %48sk/s\n",
     );
@@ -213,7 +211,7 @@ sub _p_fmt {
 sub _return_callback {
     my ( $opt, $fh, $p ) = @_;
     my $time = $p->{starttime};
-    my ( $interval, $kbs, $chunk_size, $download, $eta ) = ( 0 ) x 5;
+    my ( $interval, $bytes_per_sec, $chunk_size, $download, $eta ) = ( 0 ) x 5;
     my $resume_size = $p->{size} // 0;
     return sub {
         my ( $chunk, $res, $proto ) = @_;
@@ -224,36 +222,36 @@ sub _return_callback {
         $download = $received - $resume_size;
         $p->{total} = $res->header( 'Content-Length' ) // 0;
         if ( $download > 0 && $interval > 2 ) {
-            $p->{kbs_avg} = ( $download / 1024 ) / tv_interval[ $p->{starttime} ];
-            $eta = sec_to_time( int( ( $p->{total} - $download ) / ( $p->{kbs_avg} * 1024 ) ), 1 );
-            $p->{kbs_avg} = int( $p->{kbs_avg} );
-            $eta = undef if ! $p->{kbs_avg};
-            $kbs = int( ( $chunk_size / 1024 ) / $interval );
+            $p->{avg_bytes_per_sec} = $download / tv_interval[ $p->{starttime} ];
+            $eta = sec_to_time( int( ( $p->{total} - $download ) / $p->{avg_bytes_per_sec} ), 1 );
+            $eta = undef if ! $p->{avg_bytes_per_sec};
+            $bytes_per_sec = $chunk_size / $interval;
             $interval = 0;
             $chunk_size = 0;
         }
         my ( $info1, $info2 );
-        my $exp = { 'M' => 2, 'G' => 3 };
+        my $avg_speed = format_bytes_per_sec( $p->{avg_bytes_per_sec} );
+        my $speed     = format_bytes_per_sec( $bytes_per_sec );
+        my $exp       = { 'M' => 2, 'G' => 3 };
         if ( $p->{total} ) {
             $p->{total} += $resume_size if $resume_size;
-            my $thresh = 100_000_000 * 2 ** ( $opt->{kb_sec_len} - 2 );
             my $percent = ( $received / $p->{total} ) * 100;
             my $unit = length $p->{total} <= 10 ? 'M' : 'G';
             my $prec = 2;
             $info1 = sprintf _p_fmt( $opt, "info_row1" ),
                                 $prec, $p->{total} / 1024 ** $exp->{$unit}, $unit,
                                 'ETA ' . ( $eta || '-:--:--' ),
-                                $p->{kbs_avg} || '--';
+                                $avg_speed;
             $info2 = sprintf _p_fmt( $opt, "info_row2" ),
                                 $prec, $received / 1024 ** $exp->{$unit}, $unit,
-                                $p->{total} > $thresh ? 2 : 1, $percent,
-                                $kbs || '--';
+                                $percent,
+                                $speed;
         }
         else {
             my $unit = length $received <= 10 ? 'M' : 'G';
             my $prec = 2;
-            $info1 = sprintf _p_fmt( $opt, "info_nt_row1" ), 'Could not fetch total file-size!', $p->{kbs_avg} || '--';
-            $info2 = sprintf _p_fmt( $opt, "info_nt_row2" ), $prec, $received / 1024 ** $exp->{$unit}, $unit, $kbs || '--';
+            $info1 = sprintf _p_fmt( $opt, "info_nt_row1" ), 'Could not fetch total file-size!', $avg_speed;
+            $info2 = sprintf _p_fmt( $opt, "info_nt_row2" ), $prec, $received / 1024 ** $exp->{$unit}, $unit, $speed;
         }
         print "\r", clline, $info1;
         print "\r", clline, $info2;
@@ -285,7 +283,7 @@ sub _archive_download {
 }
 
 
-sub _is_in_download_archive{
+sub is_in_download_archive{
     my ( $opt, $info, $ex, $video_id, $fmt ) = @_;
     my $filename = catfile $opt->{archive_dir}, sprintf 'downloads_%s.json', $ex;
     return   if ! -f encode_fs( $opt, $filename );
