@@ -59,10 +59,13 @@ sub sanitize_for_path {
 
 sub timestamp_to_upload_date {
     my ( $opt, $info, $ex, $video_id, $file ) = @_;
+    return if $info->{$ex}{$video_id}{upload_datetime} eq $opt->{no_upload_datetime};
     if ( $info->{$ex}{$video_id}{upload_datetime} =~ /^(\d\d\d\d)-(\d\d)-(\d\d)T(\d\d):(\d\d):(\d\d)\z/ ) {
-        my $time = timelocal( $6, $5, $4, $3, $2 - 1, $1 );
-        my $ref = File::Touch->new( time => $time );
-        my $count = $ref->touch( encode_fs( $opt, $file ) );
+        eval {
+            my $time = timelocal( $6, $5, $4, $3, $2 - 1, $1 );
+            my $ref = File::Touch->new( time => $time );
+            my $count = $ref->touch( encode_fs( $opt, $file ) );
+        } or warn $@;
     }
 }
 
