@@ -53,15 +53,16 @@ sub uploader_history_menu {
 
             CHANNEL: while ( 1 ) {
                 my $confirm = '  CONFIRM';
-                my @pre = ( undef, $confirm );
+                my $hidden  = 'Your choice:';
+                my @pre = ( $hidden, undef, $confirm );
                 my $choices = _available_uploader( \@pre, $sticky, $history, $removed_next );
                 # Choose
                 my @indexes = choose(
                     $choices,
-                    { prompt => $prompt . "\nYour choice:", layout => 3, index => 1,
+                    { prompt => $prompt . "\n", layout => 3, index => 1, default => 1,
                         undef => '  BACK', no_spacebar => [ 0 .. $#pre ] }
                 );
-                if ( ! $indexes[0] ) {
+                if ( ! defined $indexes[0] || ! defined $choices->[$indexes[0]] ) {
                     if ( @ids ) {
                         $prompt = 'Channels:' . "\n";
                         ( $sticky,  $sticky_url ) = _sticky_name_and_url( $opt->{sticky} );
@@ -74,6 +75,19 @@ sub uploader_history_menu {
                     }
                 }
                 else {
+                    if ( $choices->[$indexes[0]] eq $hidden ) {
+                        $prompt = 'Chosen:' . "\n";
+                        ( $sticky,  $sticky_url ) = _sticky_name_and_url( $opt->{sticky} );
+                        ( $history, $history_url, $removed_next ) = _history_name_and_url( $opt, $opt->{history} );
+                        @ids = ();
+                        for my $i ( 0 .. $#$sticky_url ) {
+                            $prompt .= sprintf "= %s (%s)\n", $sticky->[$i], $opt->{sticky}{$sticky_url->[$i]}{uploader_id};
+                            push @ids, $sticky_url->[$i];
+                        }
+                        @$sticky_url = ();
+                        @$sticky     = ();
+                        next CHANNEL;
+                    }
                     my $confirmed;
                     if ( $choices->[$indexes[0]] eq $confirm ) {
                         shift @indexes;
@@ -109,7 +123,7 @@ sub uploader_history_menu {
                 my @pre = ( undef );
                 my $idx = choose(
                     [ @pre, map( "+ $_", @$sticky ), map( "- $_", @$history ) ],
-                    { prompt => 'Choose:', layout => 3, index => 1, undef => '  <<' }
+                    { prompt => 'Stickify:', layout => 3, index => 1, undef => '  <<' }
                 );
                 if ( ! $idx ) {
                     if ( $changed ) {
