@@ -14,7 +14,8 @@ use File::Spec::Functions qw( catfile catdir );
 
 use Term::Choose qw( choose );
 
-use App::YTDL::Helper qw( get_filename timestamp_to_upload_date check_mapping_stdout encode_fs uni_capture uni_system );
+use App::YTDL::Download qw( is_in_download_archive );
+use App::YTDL::Helper   qw( get_filename timestamp_to_upload_date check_mapping_stdout encode_fs uni_capture uni_system );
 
 
 
@@ -30,6 +31,9 @@ sub search_and_merge {
                 my $height = '';
                 if ( ! eval {
                     for my $fmt ( keys %{$info->{$ex}{$video_id}{file_name}} ) {
+                        if ( $opt->{skip_archived_videos} && is_in_download_archive( $opt, $info, $ex, $video_id, $fmt ) ) {
+                            die "In download archive";
+                        }
                         my $file = $info->{$ex}{$video_id}{file_name}{$fmt};
                         my $stream_info = _get_stream_info( $opt, $file );
                         if ( $stream_info =~ /^\s*codec_type=audio\s*$/m && $stream_info !~ /^\s*codec_type=video\s*$/m ) {
@@ -44,8 +48,13 @@ sub search_and_merge {
                     }
                     1 }
                 ) {
-                    say "$video_id - Merge: ", check_mapping_stdout( $opt, $@ );
-                    push @{$opt->{error_merge}}, $video_id;
+                    if ( $@ =~ /^In download archive/ ) {
+                        say "$video_id in the download archive - skipped merge!";
+                    }
+                    else {
+                        say "$video_id - Merge: ", check_mapping_stdout( $opt, $@ );
+                        push @{$opt->{error_merge}}, $video_id;
+                    }
                     next VIDEO_ID;
                 }
                 if ( ! $audio ) { #
